// Copyright 2015, The Gtk-rs Project Developers.
// See the COPYRIGHT file at the top-level directory of this distribution.
// Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>

//! Traits intended for blanket imports.

pub use auto::traits::*;
pub use cairo_interaction::ContextExt;
pub use window::WindowExtManual;
